Learn R Programming

ggdemetra (version 0.2.9)

ts2df: Convert 'ts' object to 'data.frame'

Description

Function to a ts or mts object to a data.frame that can be directly used in the plot functions.

Usage

ts2df(x)

Value

a data.frame object.

Arguments

x

a ts or mts object.

Examples

Run this code
# To get the ipi_c_eu_df object:
ts2df(ipi_c_eu)

Run the code above in your browser using DataLab