powered by
Function to a ts or mts object to a data.frame that can be directly used in the plot functions.
ts
mts
data.frame
ts2df(x)
a data.frame object.
a ts or mts object.
# To get the ipi_c_eu_df object: ts2df(ipi_c_eu)
Run the code above in your browser using DataLab